#!/usr/bin/env python

import argparse
import os
import re

from iniparse import ConfigParser, DuplicateSectionError

parser = argparse.ArgumentParser(description='Add a new tito releaser')
parser.add_argument('rhel_branch', help='rhel_branch (ex. rhel-7.3)')
parser.add_argument('placeholder_bz', help='bug id of placeholder bz (ex. 1328559)')

args = parser.parse_args()

''' Produces something like follows
[rhel-7.3]
releaser = tito.release.DistGitReleaser
branches = rhel-7.3
required_bz_flags = rhel-7.3.0+
placeholder_bz = 1328559
'''
config = ConfigParser()
config.read('rel-eng/releasers.conf')
try:
    config.add_section(args.rhel_branch)
except DuplicateSectionError:
    pass  # we'll ignore this.
config.set(args.rhel_branch, 'releaser', 'tito.release.DistGitReleaser')
config.set(args.rhel_branch, 'branches', args.rhel_branch)
config.set(args.rhel_branch, 'required_bz_flags', '{}.0+'.format(args.rhel_branch))
config.set(args.rhel_branch, 'placeholder_bz', args.placeholder_bz)

with open('rel-eng/releasers.conf', 'wb') as configfile:
    config.write(configfile)

pretty_version = re.match('rhel-(.*)', args.rhel_branch).group(1)
print('tito releaser created.')
command = './build.sh && git commit -a -m "{bz}: Rebase subscription-manager-migration-data component to the latest upstream branch for RHEL {rhel_version}"'.format(bz=args.placeholder_bz, rhel_version=pretty_version)
if raw_input('build and commit? (y/n) ').strip().lower() == 'y':
    os.system(command)
else:
    print('suggested commands for later:')
    print(command)



#!/usr/bin/python

import os
import re
import sys
import glob


def error(msg):
    sys.stderr.write(msg)
    sys.stderr.write("\n")


def fatal_error(msg):
    error(msg)
    sys.exit(-1)


class MappingValidator(object):
    def __init__(self, path):
        self._path = path
        self._mapping = {}
        self._dupes = set()
        self.successful = True

    def load_mapping(self):
        mapping_file = os.path.join(self._path, "channel-cert-mapping.txt")

        # copypasta'd from rhn-migrate-classic-to-rhsm. here's hoping it won't
        # change!
        f = open(mapping_file)
        lines = f.readlines()
        for line in lines:
            if re.match("^[a-zA-Z]", line):
                line = line.replace("\n", "")
                key, val = line.split(": ")
                if key not in self._mapping.keys():
                    self._mapping[key] = val
                else:
                    self._dupes.add(key)

    def check_for_dupes(self):
        for dupe in self._dupes:
            error("Duplicate channel mapping found: %s" % dupe)
            self.successful = False

    def filter_out_none_mappings(self):
        # remove any channels that map to none from further tests.
        # NB: the value must be _EXACTLY_ "none" to be filtered,
        # just as the migrate script does.
        for key in self._mapping.keys():
            if self._mapping[key] == "none":
                del self._mapping[key]

    def check_for_valid_pem_files(self):
        for key, val in self._mapping.items():
            pem_path = os.path.join(self._path, val)
            if not os.path.exists(pem_path):
                error('Missing pem file: "%s: %s"' % (key, val))
                self.successful = False
            else:
                f = open(pem_path, 'r')
                line = f.readline()
                if not line.startswith("-----BEGIN CERTIFICATE-----"):
                    error('Does not appear to be a PEM file: "%s: %s"'
                            % (key, val))
                    self.successful = False

    def check_for_extra_pem_files(self):
        pem_files = glob.glob(os.path.join(self._path, "*.pem"))
        pem_files = map(os.path.basename, pem_files)
        for pem_file in pem_files:
            if not pem_file in self._mapping.values():
                error("%s is unused." % pem_file)
                self.successful = False


def main():
    if len(sys.argv) == 1:
        fatal_error("Please provide a directory to validate")

    validator = MappingValidator(sys.argv[1])

    validator.load_mapping()
    validator.check_for_dupes()
    validator.filter_out_none_mappings()
    validator.check_for_valid_pem_files()
    validator.check_for_extra_pem_files()

    if not validator.successful:
        fatal_error("Errors found!")

if __name__ == "__main__":
    main()



#!/usr/bin/python

import os
import re
import shutil
import sys
import simplejson as json
from optparse import OptionParser


class MappingCreator(object):
    def __init__(self, json_file, outfile):
        f = open(json_file)
        self.data = json.load(f)
        self.outfile = outfile

    def invalid_channel(self, channel):
        return bool(re.search("-(htb$|htb-)", channel))

    def generate_mapping(self):
        mapping = {}

        for channel, details in self.data.items():
            if self.invalid_channel(channel):
                error("Skipping invalid channel: %s" % channel)
                continue
            if channel in mapping:
                fatal_error("%s is in the JSON more than once." % channel)
            mapping[channel] = os.path.basename(details['Product Cert file'])

        if self.outfile:
            f = open(self.outfile, "w")

        for k, v in sorted(mapping.items()):
            line = "%s: %s" % (k, v)
            if self.outfile:
                f.write(line + "\n")
            else:
                print line

    def copy_certs(self, certdir, certdest):
        if not os.path.exists(certdest):
            os.mkdir(certdest)
        for channel, details in self.data.items():
            if self.invalid_channel(channel):
                continue
            src = details['Product Cert file']
            if src[0] == "/":
                src = src[1:]
            src = os.path.join(certdir, src)
            try:
                shutil.copy(src, certdest)
            except IOError as e:
                error("Couldn't copy file: %s" % e)


def error(msg):
    sys.stderr.write(msg)
    sys.stderr.write("\n")


def fatal_error(msg):
    error(msg)
    sys.exit(-1)


def parse_command_line():
    parser = OptionParser()
    parser.add_option("-c", "--cert-directory", dest="certdir",
            help="Directory containing product certs.")
    parser.add_option("-o", "--out",
            help="File to write mapping to.")
    parser.add_option("-j", "--json",
            help="JSON file containing mapping information.")
    parser.add_option("-d", "--cert-destination", dest="certdest",
            help="Directory to copy certs to")
    (ops, args) = parser.parse_args()

    if ops.certdest:
        if not ops.certdir:
            parser.error("Please provide a cert directory to read the product certs from.")
        if not os.path.isdir(ops.certdir):
            parser.error("Could not find directory '%s'." % ops.certdir)
    if ops.certdir and not ops.certdest:
        parser.error("Please provide a destination to copy the certs to.")
    if not ops.json:
        parser.error("Please provide a JSON file.")
    if not os.path.isfile(ops.json):
        parser.error("Could not find file '%s'." % ops.json)

    return (ops, args)


def main():
    (ops, args) = parse_command_line()
    creator = MappingCreator(ops.json, ops.out)
    creator.generate_mapping()
    if ops.certdir and ops.certdest:
        creator.copy_certs(ops.certdir, ops.certdest)

if __name__ == "__main__":
    main()
